@@ -235,6 +235,7 @@ bool Maildir::getUpdates(bool doscan, unsigned int type,
 
   unsigned int exists = 0;
   unsigned int recent = 0;
+  bool displayExists = false;
 
   // count messages, find recent
   if (!readOnly && (type & PendingUpdates::EXPUNGE)) {  
@@ -247,6 +248,8 @@ bool Maildir::getUpdates(bool doscan, unsigned int type,
       if (message.isExpunged()) {
 	updates.addExpunged(i.getSqnr());
 	i.erase();
+	mailboxchanged = true;
+	displayExists = true;
       } else
 	++i;
     }
@@ -261,7 +264,7 @@ bool Maildir::getUpdates(bool doscan, unsigned int type,
     if (message.getStdFlags() & Message::F_RECENT) ++recent;
   }
 
-  if (exists != oldexists)
+  if (displayExists || exists != oldexists)
     updates.setExists(oldexists = exists);
 
   if (recent != oldrecent)
@@ -287,6 +290,9 @@ bool Maildir::getUpdates(bool doscan, unsigned int type,
 //------------------------------------------------------------------------
 bool Maildir::isMailbox(const std::string &s_in) const
 {
+  if (s_in == "")
+    return false;
+
   struct stat mystat;
 
   return ((stat((s_in + "/cur").c_str(), &mystat) == 0
@@ -334,6 +340,9 @@ bool Maildir::isMarked(const std::string &s_in) const
 //------------------------------------------------------------------------
 unsigned int Maildir::getStatusID(const string &path) const 
 {
+  if (path == "")
+    return 0;
+
   unsigned int statusid = 0;
   struct stat mystat;
   if (stat((path + "/new").c_str(), &mystat) == 0)
@@ -764,6 +773,9 @@ MaildirMessage *Maildir::get(const std::string &id)
 //------------------------------------------------------------------------
 void Maildir::add(MaildirMessage &m)
 {
+  MessageMap::iterator it = messages.find(m.getUID());
+  if (it != messages.end())
+    messages.erase(it);
   messages.insert(make_pair(m.getUID(), m));
   index.insert(m.getUnique(), m.getUID());
 }
