@@ -615,7 +615,14 @@ int MaildirMessage::getFile(void) const
     oflags |= O_LARGEFILE;
 #endif
     while ((fd = open(fpath.c_str(), oflags)) == -1) {
-      if (errno != ENOENT) {
+      if (errno == ENOENT) {
+        struct stat st;
+        if (lstat(fpath.c_str(), &st) != -1) {
+           IO &logger = IOFactory::getInstance().get(2);
+           logger << "dangling symlink: " << fpath << endl;
+           return -1;
+        }
+      } else {
 	IO &logger = IOFactory::getInstance().get(2);
 	logger << "unable to open " << fpath << ": "
 	       << strerror(errno) << endl;
