@@ -369,7 +369,7 @@ Operator::ProcessResult FetchOperator::process(Depot &depot,
 	  size = message.getBodySize(fatt.section, fatt.offsetstart, 
 				     fatt.offsetlength);
 	    
-	com << "{" << size << "}\r\n";
+	com << " {" << size << "}\r\n";
 	    
 	if (fatt.sectiontext == "" && fatt.section == "")
 	  message.printDoc(fatt.offsetstart, 
@@ -407,7 +407,8 @@ Operator::ProcessResult FetchOperator::process(Depot &depot,
   if (!pendingUpdates(mailbox,
 		      PendingUpdates::FLAGS
 		      | PendingUpdates::EXISTS
-		      | PendingUpdates::RECENT,
+		      | PendingUpdates::RECENT
+		      | PendingUpdates::EXPUNGE,
 		      true)) {
     IO &logger = IOFactory::getInstance().get(2);
     logger << "when scanning mailbox: "
