@@ -541,7 +541,7 @@ Operator::ProcessResult SearchOperator::process(Depot &depot,
   Mailbox *mailbox = depot.getSelected();
 
   if (command.getCharSet() != "" && command.getCharSet() != "US-ASCII") {
-    session.setLastError("[BADCHARSET (\"US-ASCII\")]");
+    session.setResponseCode("BADCHARSET (\"US-ASCII\")");
     return NO;
   }
 
