@@ -63,9 +63,6 @@ Operator::ParseResult Binc::expectThisString(const string &s_in)
   IO &com = IOFactory::getInstance().get(1);
   Session &session = Session::getInstance();
 
-#ifdef DEBUG
-  cout << "expectThisString(\"" << s_in << "\")" << endl << flush;
-#endif
   string tmp;
 
   bool match = true;
