@@ -553,6 +553,7 @@ bool Session::saveSubscribes(void) const
   if (fd == -1) {
     logger << "unable to create temporary file \""
 	   << tpl << "\"" << endl;
+    delete [] ftemplate;
     return false;
   }
 
@@ -570,15 +571,22 @@ bool Session::saveSubscribes(void) const
     }
   }
   
-  fsync(fd);
-  close(fd);
+  if (fsync(fd) != 0 || close(fd) != 0) {
+      logger << "failed to close " << ftemplate 
+	     << ": " << strerror(errno) << endl;
+      delete [] ftemplate;
+      return false;
+  }
+ 
   if (rename(ftemplate, ".bincimap-subscribed") != 0) {
       logger << "failed to rename " << ftemplate 
 	     << " to .bincimap-subscribed: "
 	     << strerror(errno) << endl;
+      delete [] ftemplate;
       return false;
   }
 
+  delete [] ftemplate;
   return true;
 }
 
